==> s-s3-aggregate-0.0.1.tgz: package/index.js <==

/**
 * Module dependencies.
 */

var debug = require('debug')('s3-aggregate');
var Emitter = require('events').EventEmitter;
var assert = require('assert');
var Batch = require('batch');

/**
 * Expose `Aggregator`.
 */

module.exports = Aggregator;

/**
 * Initialize a new aggregator.
 *
 * @param {Object} opts
 * @api public
 */

function Aggregator(opts) {
  if (!(this instanceof Aggregator)) return new Aggregator(opts);
  this.required = opts.required;
  this.output = opts.output;
  this.client = opts.client;
  this.files = opts.files;
  assert(this.output, '.output required');
  assert(this.client, '.client required');
  assert(this.files, '.files required');
  this.start();
}

/**
 * Inherit from `Emitter.prototype`.
 */

Aggregator.prototype.__proto__ = Emitter.prototype;

/**
 * Start fetching files.
 *
 * @api private
 */

Aggregator.prototype.start = function(){
  var batch = new Batch;
  var self = this;

  batch.concurrency(1);

  batch.on('progress', function(e){
    self.emit('progress', e);
  });

  this.files.forEach(function(file){
    batch.push(function(done){
      self.get(file, done);
    });
  });

  debug('streaming %j', this.files);
  batch.end(function(err){
    if (err) return self.emit('error', err);
    self.emit('end');
  });
};

/**
 * Get `file`.
 *
 * @param {String} file
 * @param {Function} fn
 * @api private
 */

Aggregator.prototype.get = function(file, fn){
  debug('get %s', file);
  var req = this.client.get(file);
  var out = this.output;
  var self = this;

  req.on('response', function(res){
    debug('%s response %s', file, res.statusCode);
    var s = res.statusCode / 100 | 0;

    if (4 == s) {
      if (self.required) {
        var err = new Error(res.statusCode + ' response');
        err.status = res.statusCode;
        err.file = file;
        return fn(err);
      } else {
        self.emit('failed', { file: file, status: res.statusCode });
        return fn();
      }
    }

    res.pipe(out);
    res.on('error', fn);
    res.on('end', fn);
  });

  req.end();
};

==> s-s3-aggregate-0.1.0.tgz: package/index.js <==

/**
 * Module dependencies.
 */

var debug = require('debug')('s3-aggregate');
var Emitter = require('events').EventEmitter;
var assert = require('assert');
var Batch = require('batch');
var zlib = require('zlib');

/**
 * Expose `Aggregator`.
 */

module.exports = Aggregator;

/**
 * Initialize a new aggregator.
 *
 * @param {Object} opts
 * @api public
 */

function Aggregator(opts) {
  if (!(this instanceof Aggregator)) return new Aggregator(opts);
  this.required = opts.required;
  this.output = opts.output;
  this.client = opts.client;
  this.files = opts.files;
  assert(this.output, '.output required');
  assert(this.client, '.client required');
  assert(this.files, '.files required');
  this.start();
}

/**
 * Inherit from `Emitter.prototype`.
 */

Aggregator.prototype.__proto__ = Emitter.prototype;

/**
 * Start fetching files.
 *
 * @api private
 */

Aggregator.prototype.start = function(){
  var batch = new Batch;
  var self = this;

  batch.concurrency(1);

  batch.on('progress', function(e){
    self.emit('progress', e);
  });

  this.files.forEach(function(file){
    batch.push(function(done){
      self.get(file, done);
    });
  });

  debug('streaming %j', this.files);
  batch.end(function(err){
    if (err) return self.emit('error', err);
    self.emit('end');
  });
};

/**
 * Get `file`.
 *
 * @param {String} file
 * @param {Function} fn
 * @api private
 */

Aggregator.prototype.get = function(file, fn){
  debug('get %s', file);
  var req = this.client.get(file);
  var out = this.output;
  var self = this;

  req.on('response', function(res){
    debug('%s response %s', res.statusCode, file);
    var s = res.statusCode / 100 | 0;

    if (4 == s) {
      if (self.required) {
        var err = new Error(res.statusCode + ' response');
        err.status = res.statusCode;
        err.file = file;
        return fn(err);
      } else {
        self.emit('failed', { file: file, status: res.statusCode });
        return fn();
      }
    }

    var gunzip = zlib.createGunzip();
    res.pipe(gunzip, { end: false }).pipe(out);
    gunzip.on('error', fn);
    out.on('end', fn);
    out.on('error', fn);
    res.on('error', fn);
  });

  req.end();
};
